MoneyManager = {}

function MoneyManager:loadMap()
    print("MoneyManager: Loading map...")
    -- Check if addConsoleCommand exists and register the command
    if addConsoleCommand ~= nil then
        addConsoleCommand("addmoney", "Adds money to the farm balance (Admins only)", "addMoneyCommand", self)
        print("MoneyManager: 'addmoney' command registered successfully.")
    else
        print("Error: addConsoleCommand is not available in this environment.")
    end
end

function MoneyManager:addMoneyCommand(amountStr, ...)
    -- Combine all extra arguments into a "reason"
    local reason = table.concat({...}, " ") or "No reason specified"

    -- Check if the user is an administrator
    if not self:isAdmin() then
        print("Only administrators can execute this command.")
        g_currentMission:addIngameNotification(FSBaseMission.INGAME_NOTIFICATION_ERROR, "Only administrators can execute this command.")
        return
    end

    -- Validate the amount input
    local amount = tonumber(amountStr)
    if not amount or amount <= 0 then
        print("Invalid amount entered. Please provide a positive number.")
        g_currentMission:addIngameNotification(FSBaseMission.INGAME_NOTIFICATION_ERROR, "Invalid amount. Please provide a positive number.")
        return
    end

    -- Checks if you are in an active game
    if g_currentMission then
        local farm = g_farmManager:getFarmById(g_currentMission:getFarmId())
        if farm and farm.changeBalance then
            farm:changeBalance(amount, MoneyType.OTHER)

            -- Get the admin's name
            local userId = g_currentMission.playerUserId
            local user = g_currentMission.userManager:getUserByUserId(userId)
            local userName = user and user.nickname or "Unknown Admin"

            -- Logs action and allows you to specify a reason
            print(string.format("Admin '%s' added $%d to the farm balance. Reason: %s", userName, amount, reason))
            g_currentMission:addIngameNotification(FSBaseMission.INGAME_NOTIFICATION_OK, string.format("Added $%d to the farm balance. Reason: %s", amount, reason))
        else
            print("Error: Farm not found or balance cannot be updated.")
            g_currentMission:addIngameNotification(FSBaseMission.INGAME_NOTIFICATION_ERROR, "Farm not found or cannot update balance.")
        end
    else
        print("Error: No active game session found.")
        g_currentMission:addIngameNotification(FSBaseMission.INGAME_NOTIFICATION_ERROR, "No active game session found.")
    end
end

function MoneyManager:isAdmin()
    -- Check if the current player is an admin
    if g_currentMission:getIsServer() then
        return true
    elseif g_currentMission.isMasterUser then
        return true
    elseif g_currentMission.userManager and g_currentMission.userManager:getUserByUserId(g_currentMission.playerUserId) then
        return g_currentMission.userManager:getUserByUserId(g_currentMission.playerUserId):getIsMasterUser()
    end
    return false
end

-- Register the MoneyManager as an event listener
addModEventListener(MoneyManager)
